impl

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 30, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Overview

package impl provides the SDK implementation for interacting with the Onyx Database service. All networked behavior, resolvers, and client wiring will be implemented here.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ClearConfigCache

func ClearConfigCache()

ClearConfigCache clears the resolver cache.

func Init

func Init(ctx context.Context, cfg Config) (contract.Client, error)

Init constructs a client using the provided configuration.

func InitWithDatabaseID

func InitWithDatabaseID(ctx context.Context, databaseID string) (contract.Client, error)

InitWithDatabaseID initializes a client using only the database ID and environment/file configuration.

Types

type Config

type Config = contract.Config

Config mirrors contract.Config to avoid import churn.

Directories

Path Synopsis

Jump to